A dataframe with information about stream gages within a county for
a specified time frame. This information typically includes each gage's
site number, station name, agency code, site type code, latitude,
longitude, and county code. See the whatNWISsites function from
the dataRetrieval package for details.